.. include:: /_includes/wip_prolog.rst

API Reference
=============

The *python-stix* APIs are the recommended tools for reading, writing, and manipulating STIX XML documents.

.. note::

   The python-stix APIs are currently under development. As such, API coverage of STIX data constructs is incomplete; please bear with us as we work toward complete coverage. This documentation also serves to outline current API coverage.

STIX
----
Modules located in the base `stix`_ package

.. _stix: https://github.com/STIXProject/python-stix/tree/master/stix

.. toctree::
   :titlesonly:

   base
   data_marking

STIX Campaign
-------------
Modules located in the `stix.campaign`_ package

.. _stix.campaign: https://github.com/STIXProject/python-stix/tree/master/stix/campaign

.. toctree::
   :titlesonly:
   :glob:

   campaign/*

STIX Common
-----------
Modules located in the `stix.common`_ package

.. _stix.common: https://github.com/STIXProject/python-stix/tree/master/stix/common

.. toctree::
   :titlesonly:
   :glob:

   common/common
   common/*

STIX Core
---------
Modules located in the `stix.core`_ package

.. _stix.core: https://github.com/STIXProject/python-stix/tree/master/stix/core

.. toctree::
   :titlesonly:
   :glob:

   core/*

STIX Course of Action (COA)
---------------------------
Modules located in the `stix.coa`_ package

.. _stix.coa: https://github.com/STIXProject/python-stix/tree/master/stix/coa

.. toctree::
   :titlesonly:
   :glob:

   coa/coa
   coa/*

STIX Exploit Target
-------------------
Modules located in the `stix.exploit_target`_ package

.. _stix.exploit_target: https://github.com/STIXProject/python-stix/tree/master/stix/exploit_target

.. toctree::
   :titlesonly:
   :glob:

   exploit_target/exploit_target
   exploit_target/*

STIX Extensions
---------------
Modules located in the `stix.extensions`_ package

.. _stix.extensions: https://github.com/STIXProject/python-stix/tree/master/stix/extensions

.. toctree::
   :titlesonly:
   :glob:

   extensions/*/*

STIX Incident
-------------
Modules located in the `stix.incident`_ package

.. _stix.incident: https://github.com/STIXProject/python-stix/tree/master/stix/incident

.. toctree::
   :titlesonly:
   :glob:

   incident/incident
   incident/*

STIX Indicator
--------------
Modules located in the `stix.indicator`_ package

.. _stix.indicator: https://github.com/STIXProject/python-stix/tree/master/stix/indicator

.. toctree::
   :titlesonly:
   :glob:

   indicator/indicator
   indicator/*

STIX Threat Actor
-----------------
Modules located in the `stix.threat_actor`_ package

.. _stix.threat_actor: https://github.com/STIXProject/python-stix/tree/master/stix/threat_actor

.. toctree::
   :titlesonly:
   :glob:

   threat_actor/*

STIX Tactics, Techniques, and Procedures (TTP)
----------------------------------------------
Modules located in the `stix.ttp`_ package

.. _stix.ttp: https://github.com/STIXProject/python-stix/tree/master/stix/ttp

.. toctree::
   :titlesonly:
   :glob:

   ttp/ttp
   ttp/*

STIX Utils
----------
Modules located in the `stix.utils`_ package

.. _stix.utils: https://github.com/STIXProject/python-stix/tree/master/stix/utils

.. toctree::
   :titlesonly:
   :glob:

   utils/*
